from django.http import HttpRequest
from django.http import HttpResponseServerError
from django.shortcuts import render
from sentry_sdk import last_event_id


# noinspection PyUnusedLocal
def collect_500_error_user_feedback_view(request: HttpRequest, *args, **argv) -> HttpResponseServerError:
    return render(
        request,
        template_name='error_handler/500.html',
        context={'sentry_event_id': last_event_id()},
        status=500,
    )



from typing import Dict

from django.conf import settings
from django.contrib.sites.models import Site
from django.core.mail import EmailMultiAlternatives
from django.template.loader import get_template
from django_settings_export import settings_export


def send_email(
    email_subject: str,
    template_path_without_extension: str,
    template_context: dict = None,
    email_destination: str = None,
    email_headers: Dict[str, str] = None,
    email_from: str = settings.DEFAULT_FROM_EMAIL,
    email_reply_to: str = None,
):
    template_plaintext = get_template(f'{template_path_without_extension}.txt')
    template_context = _get_full_context(context_base=template_context)
    if email_reply_to:
        reply_to_header = {'Reply-To': email_reply_to}
        if email_headers is None:
            email_headers = reply_to_header
        else:
            email_headers = {**email_headers, **reply_to_header}
    email = EmailMultiAlternatives(
        subject=email_subject,
        body=template_plaintext.render(template_context),
        from_email=email_from,
        to=[email_destination],
        headers=email_headers,
    )
    template_html = get_template(f'{template_path_without_extension}.html')
    email.attach_alternative(template_html.render(template_context), 'text/html')
    email.send()


def _get_full_context(context_base: dict = None) -> dict:
    settings_exported = settings_export(request=None)
    settings_exported['site'] = Site.objects.get_current()
    settings_exported['base_url'] = settings.META_SITE_PROTOCOL + '://' + Site.objects.get_current().domain
    if context_base is None:
        return settings_exported
    else:
        return {**context_base, **settings_exported}



import importlib

from django.apps import AppConfig


class DjangoCmsHelpersConfig(AppConfig):
    name = 'djangocms_helpers'

    # noinspection PyUnresolvedReferences
    def ready(self):
        is_django_cms_installed = importlib.util.find_spec('cms') is not None
        if is_django_cms_installed:
            from djangocms_helpers.monkey_patches.static_placeholder_publishing_fix import monkeypatch_cms_has_publish_permission
            from djangocms_helpers.fixes.language_slug_fix import fix_page_slugs
            from djangocms_helpers.fixes.language_slug_fix import fix_title_path



#!/usr/bin/env python3
from setuptools import setup


setup(
    name='djangocms-helpers',
    version='2.0.1',
    author='Victor',
    author_email='victor@what.digital',
    url='https://gitlab.com/what-digital/djangocms-helpers',
    packages=[
        'djangocms_helpers',
    ],
    include_package_data=True,
    install_requires=[
        'django >= 2.2, < 3',
        'django-fieldsignals >= 0.4.0',
        'django-meta',
    ],
)



from cms.models import Title, Page
from django.dispatch import receiver
from django.db.models.signals import post_save
from fieldsignals import post_save_changed


@receiver(post_save, sender=Page)
def fix_page_slugs(sender, instance: Page, **kwargs):
    _update_child_pages(instance)


@receiver(post_save_changed, sender=Title, fields=['slug', 'path'])
def fix_title_path(sender, instance: Title, **kwargs):
    _update_child_pages(instance.page)


def _update_child_pages(page: Page):
    for language in page.get_languages():
        _update_title_path(page, language)
        for child_page in page.get_child_pages():
            _update_title_path(child_page, language)


def _update_title_path(page: Page, language: str):
    if hasattr(page.get_title_obj(language, fallback=False), 'get_path_for_base'):
        # noinspection PyProtectedMember
        page._update_title_path(language)
